@@ -1,8 +1,5 @@
 package Dancer2::Plugin::ElasticSearch;
-{
-  $Dancer2::Plugin::ElasticSearch::VERSION = '0.002';
-}
-
+$Dancer2::Plugin::ElasticSearch::VERSION = '0.003';
 # ABSTRACT: Dancer2 plugin for obtaining Search::Elasticsearch handles
 
 use strict;
@@ -14,7 +11,7 @@ use utf8;
 
 use Search::Elasticsearch;
 use Try::Tiny;
-use Dancer2::Plugin qw/:no_dsl/;
+use Dancer2::Plugin;
 
 our $handles = {};
 
@@ -65,7 +62,7 @@ Dancer2::Plugin::ElasticSearch - Dancer2 plugin for obtaining Search::Elasticsea
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
